summaryrefslogtreecommitdiffstats
path: root/src/gui/rulers/RawNoteRuler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/rulers/RawNoteRuler.cpp')
-rw-r--r--src/gui/rulers/RawNoteRuler.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/rulers/RawNoteRuler.cpp b/src/gui/rulers/RawNoteRuler.cpp
index ee159c1..75ddc37 100644
--- a/src/gui/rulers/RawNoteRuler.cpp
+++ b/src/gui/rulers/RawNoteRuler.cpp
@@ -50,9 +50,9 @@ RawNoteRuler::RawNoteRuler(RulerScale *rulerScale,
Segment *segment,
double xorigin,
int height,
- TQWidget *tqparent,
+ TQWidget *parent,
const char *name) :
- TQWidget(tqparent, name),
+ TQWidget(parent, name),
m_xorigin(xorigin),
m_height(height),
m_currentXOffset(0),
@@ -559,7 +559,7 @@ RawNoteRuler::paintEvent(TQPaintEvent* e)
// at a time when no other notes are playing (at least of
// those that started no earlier than the paint start time).
// Each node in that tree represents a note that starts
// playing during its tqparent node's note, or at the same time
// as it.
drawNode(paint, *DefaultVelocityColour::getInstance(), *fi, m_height - 3, 2);
@@ -559,7 +559,7 @@ RawNoteRuler::paintEvent(TQPaintEvent* e)
// those that started no earlier than the paint start time).
// Each node in that tree represents a note that starts
- // playing during its tqparent node's note, or at the same time
+ // playing during its parent node's note, or at the same time
// as it.
drawNode(paint, *DefaultVelocityColour::getInstance(), *fi, m_height - 3, 2);